@@ -10,9 +10,9 @@ Get software version information
 
 def release() -> str:
     """Returns the software version number"""
-    return "0.14.0"
+    return "0.15.1"
 
 
 def date() -> str:
     """Returns the creation date of this release"""
-    return "12 April 2022"
+    return "06 June 2022"
